@@ -3,13 +3,13 @@
 
 #include <time.h>
 #include <stdio.h>
-#include <malloc.h>
 #include <string.h>
 
 #ifdef _Macintosh
 #include "CyberJackUSBToolbox.h"
 #endif
 #ifdef _LINUX
+#include <malloc.h>
 #include "cjppa_linux.h"
 #endif
 
@@ -53,7 +53,8 @@ CJPP_EXP_TYPE CCID_DEVICE CJPP_CALL_CONV ctapiInit(char *cDeviceName,CCID_CTX hC
 #ifdef _WINDOWS
    char *myName;
 #endif // _WINDOWS
-   HANDLE hDevice=cjppCreate(cDeviceName);
+   HANDLE hDevice;
+   hDevice=cjppCreate(cDeviceName);
    if(hDevice==0)
       return 0;
    Result=malloc(sizeof(cjccidStruct));
@@ -151,7 +152,6 @@ CJPP_EXP_TYPE CCID_DEVICE CJPP_CALL_CONV ctapiInit(char *cDeviceName,CCID_CTX hC
 
 int cjccid_iccPowerOn(HANDLE cjDevice,unsigned char Voltage,unsigned char *ATR,int *len)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -179,7 +179,6 @@ int cjccid_iccPowerOn(HANDLE cjDevice,unsigned char Voltage,unsigned char *ATR,i
 
 int cjccid_iccPowerOff(HANDLE cjDevice)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -192,7 +191,6 @@ int cjccid_iccPowerOff(HANDLE cjDevice)
 
 int cjccid_GetSlotStatus(HANDLE cjDevice)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -217,7 +215,6 @@ int cjccid_GetSlotStatus(HANDLE cjDevice)
 
 int cjccid_SetParameters(HANDLE cjDevice,unsigned char ProtocolNum,unsigned char FI_DI,unsigned char EDC,unsigned char GuardTime,unsigned char WaitingInteger)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -257,7 +254,6 @@ int cjccid_SetParameters(HANDLE cjDevice,unsigned char ProtocolNum,unsigned char
 
 int cjccid_XfrBlock(HANDLE cjDevice,unsigned char BWI,unsigned char *out,int out_len,unsigned char *in,int *in_len,unsigned short wLevelParameter)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -315,7 +311,6 @@ CJPP_EXP_TYPE char CJPP_CALL_CONV ctapiClose(CCID_DEVICE hDevice)
 
 int cjppSetDateTime(HANDLE cjppDevice,unsigned char bOffset)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
    struct tm *t;
@@ -422,7 +417,6 @@ int cjccid_SecurePV(HANDLE cjDevice,unsigned char Timeout,
                     unsigned char Condition,unsigned char *Prologue,
                     unsigned char *out,int out_len,unsigned char *in,int *in_len)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -430,16 +424,16 @@ int cjccid_SecurePV(HANDLE cjDevice,unsigned char Timeout,
    Message.dwLength=out_len+15;
    Message.bSlot=0;
    Message.Header.Secure.bBWI=0;
-   Message.Header.Secure.wLevelParameter=0;
+   Message.Header.Secure.wLevelParameter=cjppSWAB_WORD_2(0);
    Message.Data.Secure.bPINOperation=0;
    Message.Data.Secure.bTimeOut=Timeout;
    Message.Data.Secure.bmFormatString=(unsigned char)(0x80 | (PinPosition<<3) | PinType);
    Message.Data.Secure.bmPINBlockString=(unsigned char)((PinLengthSize<<4) | PinLength);
    Message.Data.Secure.bmPINLengthFormat=PinLengthPosition;
-   Message.Data.Secure.Data.Verify.wPINMaxExtraDigit=(((unsigned short)Min)<<8)+Max;
+   Message.Data.Secure.Data.Verify.wPINMaxExtraDigit=cjppSWAB_WORD_2((((unsigned short)Min)<<8)+Max);
    Message.Data.Secure.Data.Verify.bEntryValidationCondition=Condition;
    Message.Data.Secure.Data.Verify.bNumberMessage=0xff;
-   Message.Data.Secure.Data.Verify.wLangId=0x0409;
+   Message.Data.Secure.Data.Verify.wLangId=cjppSWAB_WORD_2(0x0409);
    Message.Data.Secure.Data.Verify.bMsgIndex=0;
    memcpy(Message.Data.Secure.Data.Verify.bTeoPrologue,Prologue,3);
    memcpy(Message.Data.Secure.Data.Verify.abData,out,out_len);
@@ -478,7 +472,6 @@ int cjccid_SecureMV(HANDLE cjDevice,unsigned char Timeout,
                     unsigned char OffsetOld,unsigned char OffsetNew,
                     unsigned char *out,int out_len,unsigned char *in,int *in_len)
 {
-   int Res;
 	CCID_Message Message;
 	CCID_Response Response;
 
@@ -486,7 +479,7 @@ int cjccid_SecureMV(HANDLE cjDevice,unsigned char Timeout,
    Message.dwLength=out_len+20;
    Message.bSlot=0;
    Message.Header.Secure.bBWI=0;
-   Message.Header.Secure.wLevelParameter=0;
+   Message.Header.Secure.wLevelParameter=cjppSWAB_WORD_2(0);
    Message.Data.Secure.bPINOperation=1;
    Message.Data.Secure.bTimeOut=Timeout;
    Message.Data.Secure.bmFormatString=(unsigned char)(0x80 | (PinPosition<<3) | PinType);
@@ -494,11 +487,11 @@ int cjccid_SecureMV(HANDLE cjDevice,unsigned char Timeout,
    Message.Data.Secure.bmPINLengthFormat=PinLengthPosition;
    Message.Data.Secure.Data.Modify.bInsertionOffsetOld=OffsetOld;
    Message.Data.Secure.Data.Modify.bInsertionOffsetNew=OffsetNew;
-   Message.Data.Secure.Data.Modify.wPINMaxExtraDigit=(((unsigned short)Min)<<8)+Max;
+   Message.Data.Secure.Data.Modify.wPINMaxExtraDigit=cjppSWAB_WORD_2((((unsigned short)Min)<<8)+Max);
    Message.Data.Secure.Data.Modify.bConfirmPIN= 1 | bConfirmPIN;
    Message.Data.Secure.Data.Modify.bEntryValidationCondition=Condition;
    Message.Data.Secure.Data.Modify.bNumberMessage=0xff;
-   Message.Data.Secure.Data.Modify.wLangId=0x0409;
+   Message.Data.Secure.Data.Modify.wLangId=cjppSWAB_WORD_2(0x0409);
    Message.Data.Secure.Data.Modify.bMsgIndex1=0;
    Message.Data.Secure.Data.Modify.bMsgIndex2=0;
    Message.Data.Secure.Data.Modify.bMsgIndex3=0;
